'use strict';

var web3_js = require('@solana/web3.js');

// src/helpers.ts
async function findAuthorityPda(config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await web3_js.getProgramDerivedAddress({ programAddress, seeds: [] });
}
async function findMintProofPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("mint_proof"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findMintProofV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("mint_proof_v2"),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findWhitelistPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32).encode(seeds.uuid)]
  });
}
async function findWhitelistV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("whitelist"),
      web3_js.getAddressEncoder().encode(seeds.namespace),
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32).encode(seeds.uuid)
    ]
  });
}

// src/generated/accounts/authority.ts
function getAuthorityEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["bump", web3_js.getU8Encoder()],
      ["cosigner", web3_js.getAddressEncoder()],
      ["owner", web3_js.getAddressEncoder()],
      ["reserved", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([36, 108, 254, 18, 167, 144, 27, 36])
    })
  );
}
function getAuthorityDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["bump", web3_js.getU8Decoder()],
    ["cosigner", web3_js.getAddressDecoder()],
    ["owner", web3_js.getAddressDecoder()],
    ["reserved", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 64)]
  ]);
}
function getAuthorityCodec() {
  return web3_js.combineCodec(getAuthorityEncoder(), getAuthorityDecoder());
}
function decodeAuthority(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getAuthorityDecoder()
  );
}
async function fetchAuthority(rpc, address, config) {
  const maybeAccount = await fetchMaybeAuthority(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthority(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeAuthority(maybeAccount);
}
async function fetchAllAuthority(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAuthority(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAuthority(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeAuthority(maybeAccount));
}
function getAuthoritySize() {
  return 137;
}
async function fetchAuthorityFromSeeds(rpc, config = {}) {
  const maybeAccount = await fetchMaybeAuthorityFromSeeds(rpc, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthorityFromSeeds(rpc, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findAuthorityPda({ programAddress });
  return await fetchMaybeAuthority(rpc, address, fetchConfig);
}
function getMintProofEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["proofLen", web3_js.getU8Encoder()],
      [
        "proof",
        web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32), { size: 28 })
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([227, 131, 106, 240, 190, 48, 219, 228])
    })
  );
}
function getMintProofDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["proofLen", web3_js.getU8Decoder()],
    [
      "proof",
      web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32), { size: 28 })
    ]
  ]);
}
function getMintProofCodec() {
  return web3_js.combineCodec(getMintProofEncoder(), getMintProofDecoder());
}
function decodeMintProof(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMintProofDecoder()
  );
}
async function fetchMintProof(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProof(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProof(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMintProof(maybeAccount);
}
async function fetchAllMintProof(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProof(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProof(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProof(maybeAccount));
}
function getMintProofSize() {
  return 28;
}
async function fetchMintProofFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofPda(seeds, { programAddress });
  return await fetchMaybeMintProof(rpc, address, fetchConfig);
}
function getMintProofV2Encoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["proofLen", web3_js.getU8Encoder()],
      [
        "proof",
        web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32), { size: 28 })
      ],
      ["creationSlot", web3_js.getU64Encoder()],
      ["payer", web3_js.getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([22, 197, 150, 178, 249, 225, 183, 75])
    })
  );
}
function getMintProofV2Decoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["proofLen", web3_js.getU8Decoder()],
    [
      "proof",
      web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32), { size: 28 })
    ],
    ["creationSlot", web3_js.getU64Decoder()],
    ["payer", web3_js.getAddressDecoder()]
  ]);
}
function getMintProofV2Codec() {
  return web3_js.combineCodec(getMintProofV2Encoder(), getMintProofV2Decoder());
}
function decodeMintProofV2(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMintProofV2Decoder()
  );
}
async function fetchMintProofV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProofV2(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMintProofV2(maybeAccount);
}
async function fetchAllMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProofV2(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProofV2(maybeAccount));
}
function getMintProofV2Size() {
  return 945;
}
async function fetchMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofV2FromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofV2Pda(seeds, { programAddress });
  return await fetchMaybeMintProofV2(rpc, address, fetchConfig);
}
function getWhitelistEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getU8Encoder()],
      ["verified", web3_js.getBooleanEncoder()],
      ["rootHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["uuid", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["name", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["frozen", web3_js.getBooleanEncoder()],
      ["voc", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["fvc", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["reserved", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([204, 176, 52, 79, 146, 121, 54, 247])
    })
  );
}
function getWhitelistDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getU8Decoder()],
    ["verified", web3_js.getBooleanDecoder()],
    ["rootHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["uuid", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["name", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["frozen", web3_js.getBooleanDecoder()],
    ["voc", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["fvc", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["reserved", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 64)]
  ]);
}
function getWhitelistCodec() {
  return web3_js.combineCodec(getWhitelistEncoder(), getWhitelistDecoder());
}
function decodeWhitelist(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getWhitelistDecoder()
  );
}
async function fetchWhitelist(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelist(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelist(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeWhitelist(maybeAccount);
}
async function fetchAllWhitelist(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelist(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelist(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelist(maybeAccount));
}
function getWhitelistSize() {
  return 238;
}
async function fetchWhitelistFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistPda(seeds, { programAddress });
  return await fetchMaybeWhitelist(rpc, address, fetchConfig);
}
function getConditionEncoder() {
  return web3_js.getStructEncoder([
    ["mode", getModeEncoder()],
    ["value", web3_js.getAddressEncoder()]
  ]);
}
function getConditionDecoder() {
  return web3_js.getStructDecoder([
    ["mode", getModeDecoder()],
    ["value", web3_js.getAddressDecoder()]
  ]);
}
function getConditionCodec() {
  return web3_js.combineCodec(getConditionEncoder(), getConditionDecoder());
}
function getFullMerkleProofEncoder() {
  return web3_js.getStructEncoder([
    ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))],
    ["leaf", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)]
  ]);
}
function getFullMerkleProofDecoder() {
  return web3_js.getStructDecoder([
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))],
    ["leaf", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)]
  ]);
}
function getFullMerkleProofCodec() {
  return web3_js.combineCodec(getFullMerkleProofEncoder(), getFullMerkleProofDecoder());
}
var Mode = /* @__PURE__ */ ((Mode2) => {
  Mode2[Mode2["MerkleTree"] = 0] = "MerkleTree";
  Mode2[Mode2["VOC"] = 1] = "VOC";
  Mode2[Mode2["FVC"] = 2] = "FVC";
  return Mode2;
})(Mode || {});
function getModeEncoder() {
  return web3_js.getEnumEncoder(Mode);
}
function getModeDecoder() {
  return web3_js.getEnumDecoder(Mode);
}
function getModeCodec() {
  return web3_js.combineCodec(getModeEncoder(), getModeDecoder());
}
function getOperationEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["Noop", web3_js.getUnitEncoder()],
    ["Clear", web3_js.getUnitEncoder()],
    [
      "Set",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ]
  ]);
}
function getOperationDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["Noop", web3_js.getUnitDecoder()],
    ["Clear", web3_js.getUnitDecoder()],
    [
      "Set",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ]
  ]);
}
function getOperationCodec() {
  return web3_js.combineCodec(getOperationEncoder(), getOperationDecoder());
}
function operation(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOperation(kind, value) {
  return value.__kind === kind;
}
var State = /* @__PURE__ */ ((State2) => {
  State2[State2["Unfrozen"] = 0] = "Unfrozen";
  State2[State2["Frozen"] = 1] = "Frozen";
  return State2;
})(State || {});
function getStateEncoder() {
  return web3_js.getEnumEncoder(State);
}
function getStateDecoder() {
  return web3_js.getEnumDecoder(State);
}
function getStateCodec() {
  return web3_js.combineCodec(getStateEncoder(), getStateDecoder());
}

// src/generated/accounts/whitelistV2.ts
function getWhitelistV2Encoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["version", web3_js.getU8Encoder()],
      ["bump", web3_js.getU8Encoder()],
      ["uuid", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["state", getStateEncoder()],
      ["updateAuthority", web3_js.getAddressEncoder()],
      ["namespace", web3_js.getAddressEncoder()],
      ["freezeAuthority", web3_js.getAddressEncoder()],
      ["conditions", web3_js.getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([136, 184, 45, 191, 85, 203, 191, 119])
    })
  );
}
function getWhitelistV2Decoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["version", web3_js.getU8Decoder()],
    ["bump", web3_js.getU8Decoder()],
    ["uuid", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["state", getStateDecoder()],
    ["updateAuthority", web3_js.getAddressDecoder()],
    ["namespace", web3_js.getAddressDecoder()],
    ["freezeAuthority", web3_js.getAddressDecoder()],
    ["conditions", web3_js.getArrayDecoder(getConditionDecoder())]
  ]);
}
function getWhitelistV2Codec() {
  return web3_js.combineCodec(getWhitelistV2Encoder(), getWhitelistV2Decoder());
}
function decodeWhitelistV2(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getWhitelistV2Decoder()
  );
}
async function fetchWhitelistV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelistV2(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeWhitelistV2(maybeAccount);
}
async function fetchAllWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelistV2(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelistV2(maybeAccount));
}
function getWhitelistV2Size() {
  return 239;
}
async function fetchWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistV2Pda(seeds, { programAddress });
  return await fetchMaybeWhitelistV2(rpc, address, fetchConfig);
}

// src/generated/errors/tensorWhitelist.ts
var TENSOR_WHITELIST_ERROR__BAD_COSIGNER = 6e3;
var TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION = 6001;
var TENSOR_WHITELIST_ERROR__MISSING_NAME = 6002;
var TENSOR_WHITELIST_ERROR__BAD_WHITELIST = 6003;
var TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG = 6004;
var TENSOR_WHITELIST_ERROR__BAD_OWNER = 6005;
var TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION = 6006;
var TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION = 6007;
var TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION = 6008;
var TENSOR_WHITELIST_ERROR__NO_CONDITIONS = 6009;
var TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY = 6010;
var TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT = 6011;
var TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX = 6012;
var TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS = 6013;
var TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS = 6014;
var TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS = 6015;
var TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN = 6016;
var TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF = 6017;
var TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF = 6018;
var tensorWhitelistErrorMessages;
if (process.env.NODE_ENV !== "production") {
  tensorWhitelistErrorMessages = {
    [TENSOR_WHITELIST_ERROR__BAD_COSIGNER]: `passed in cosigner doesnt have the rights to do this`,
    [TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF]: `bad mint proof`,
    [TENSOR_WHITELIST_ERROR__BAD_OWNER]: `passed in owner doesnt have the rights to do this`,
    [TENSOR_WHITELIST_ERROR__BAD_WHITELIST]: `bad whitelist`,
    [TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS]: `cannot have empty conditions`,
    [TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION]: `failed fvc verification`,
    [TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION]: `failed merkle proof verification`,
    [TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION]: `failed voc verification`,
    [TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY]: `invalid authority`,
    [TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX]: `invalid whitelist index`,
    [TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF]: `missing mint proof`,
    [TENSOR_WHITELIST_ERROR__MISSING_NAME]: `missing name`,
    [TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION]: `missing all 3 verification methods: at least one must be present`,
    [TENSOR_WHITELIST_ERROR__NO_CONDITIONS]: `no whitelist conditions provided`,
    [TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT]: `condition at index not a merkle root`,
    [TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG]: `proof provided exceeds the limit of 32 hashes`,
    [TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS]: `too many conditions`,
    [TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS]: `too many merkle proofs`,
    [TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN]: `whitelist is frozen`
  };
}
function getTensorWhitelistErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return tensorWhitelistErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
var TENSOR_WHITELIST_PROGRAM_ADDRESS = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW";
var TensorWhitelistAccount = /* @__PURE__ */ ((TensorWhitelistAccount2) => {
  TensorWhitelistAccount2[TensorWhitelistAccount2["Authority"] = 0] = "Authority";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProofV2"] = 1] = "MintProofV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProof"] = 2] = "MintProof";
  TensorWhitelistAccount2[TensorWhitelistAccount2["WhitelistV2"] = 3] = "WhitelistV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["Whitelist"] = 4] = "Whitelist";
  return TensorWhitelistAccount2;
})(TensorWhitelistAccount || {});
function identifyTensorWhitelistAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([36, 108, 254, 18, 167, 144, 27, 36])
    ),
    0
  )) {
    return 0 /* Authority */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([22, 197, 150, 178, 249, 225, 183, 75])
    ),
    0
  )) {
    return 1 /* MintProofV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([227, 131, 106, 240, 190, 48, 219, 228])
    ),
    0
  )) {
    return 2 /* MintProof */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([136, 184, 45, 191, 85, 203, 191, 119])
    ),
    0
  )) {
    return 3 /* WhitelistV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([204, 176, 52, 79, 146, 121, 54, 247])
    ),
    0
  )) {
    return 4 /* Whitelist */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorWhitelist account."
  );
}
var TensorWhitelistInstruction = /* @__PURE__ */ ((TensorWhitelistInstruction2) => {
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelist"] = 0] = "FreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateAuthority"] = 1] = "InitUpdateAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateMintProof"] = 2] = "InitUpdateMintProof";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateWhitelist"] = 3] = "InitUpdateWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocAuthority"] = 4] = "ReallocAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocWhitelist"] = 5] = "ReallocWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelist"] = 6] = "UnfreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CreateWhitelistV2"] = 7] = "CreateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UpdateWhitelistV2"] = 8] = "UpdateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateMintProofV2"] = 9] = "InitUpdateMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CloseMintProofV2"] = 10] = "CloseMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelistV2"] = 11] = "FreezeWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelistV2"] = 12] = "UnfreezeWhitelistV2";
  return TensorWhitelistInstruction2;
})(TensorWhitelistInstruction || {});
function identifyTensorWhitelistInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([248, 112, 12, 150, 175, 238, 38, 184])
    ),
    0
  )) {
    return 0 /* FreezeWhitelist */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([53, 144, 79, 150, 196, 110, 22, 55])
    ),
    0
  )) {
    return 1 /* InitUpdateAuthority */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([30, 77, 123, 9, 191, 37, 52, 159])
    ),
    0
  )) {
    return 2 /* InitUpdateMintProof */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([255, 1, 192, 134, 111, 49, 212, 131])
    ),
    0
  )) {
    return 3 /* InitUpdateWhitelist */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([128, 120, 16, 197, 85, 34, 2, 91])
    ),
    0
  )) {
    return 4 /* ReallocAuthority */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([173, 147, 168, 152, 181, 46, 55, 60])
    ),
    0
  )) {
    return 5 /* ReallocWhitelist */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([215, 119, 9, 92, 160, 139, 226, 253])
    ),
    0
  )) {
    return 6 /* UnfreezeWhitelist */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([31, 207, 213, 77, 105, 13, 127, 98])
    ),
    0
  )) {
    return 7 /* CreateWhitelistV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([184, 188, 157, 214, 205, 49, 74, 226])
    ),
    0
  )) {
    return 8 /* UpdateWhitelistV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([35, 185, 181, 108, 143, 139, 228, 45])
    ),
    0
  )) {
    return 9 /* InitUpdateMintProofV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([237, 78, 8, 208, 47, 148, 145, 170])
    ),
    0
  )) {
    return 10 /* CloseMintProofV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([69, 158, 243, 78, 116, 68, 221, 113])
    ),
    0
  )) {
    return 11 /* FreezeWhitelistV2 */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([51, 105, 214, 84, 252, 188, 26, 1])
    ),
    0
  )) {
    return 12 /* UnfreezeWhitelistV2 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorWhitelist instruction."
  );
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/generated/instructions/closeMintProofV2.ts
function getCloseMintProofV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([237, 78, 8, 208, 47, 148, 145, 170])
    })
  );
}
function getCloseMintProofV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getCloseMintProofV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseMintProofV2InstructionDataEncoder(),
    getCloseMintProofV2InstructionDataDecoder()
  );
}
function getCloseMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCloseMintProofV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      signer: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCloseMintProofV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateWhitelistV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["uuid", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["freezeAuthority", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["conditions", web3_js.getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([31, 207, 213, 77, 105, 13, 127, 98])
    })
  );
}
function getCreateWhitelistV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["uuid", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["freezeAuthority", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["conditions", web3_js.getArrayDecoder(getConditionDecoder())]
  ]);
}
function getCreateWhitelistV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateWhitelistV2InstructionDataEncoder(),
    getCreateWhitelistV2InstructionDataDecoder()
  );
}
async function getCreateWhitelistV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistV2Pda({
      namespace: expectAddress(accounts.namespace.value),
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      namespace: getNextAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([248, 112, 12, 150, 175, 238, 38, 184])
    })
  );
}
function getFreezeWhitelistInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getFreezeWhitelistInstructionDataCodec() {
  return web3_js.combineCodec(
    getFreezeWhitelistInstructionDataEncoder(),
    getFreezeWhitelistInstructionDataDecoder()
  );
}
async function getFreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getFreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getFreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([69, 158, 243, 78, 116, 68, 221, 113])
    })
  );
}
function getFreezeWhitelistV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getFreezeWhitelistV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getFreezeWhitelistV2InstructionDataEncoder(),
    getFreezeWhitelistV2InstructionDataDecoder()
  );
}
function getFreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getFreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getFreezeWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getInitUpdateAuthorityInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["newCosigner", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["newOwner", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([53, 144, 79, 150, 196, 110, 22, 55])
    })
  );
}
function getInitUpdateAuthorityInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["newCosigner", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["newOwner", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getInitUpdateAuthorityInstructionDataCodec() {
  return web3_js.combineCodec(
    getInitUpdateAuthorityInstructionDataEncoder(),
    getInitUpdateAuthorityInstructionDataDecoder()
  );
}
async function getInitUpdateAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateMintProofInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([30, 77, 123, 9, 191, 37, 52, 159])
    })
  );
}
function getInitUpdateMintProofInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getInitUpdateMintProofInstructionDataCodec() {
  return web3_js.combineCodec(
    getInitUpdateMintProofInstructionDataEncoder(),
    getInitUpdateMintProofInstructionDataDecoder()
  );
}
async function getInitUpdateMintProofInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofPda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateMintProofInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateMintProofInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      mint: getNextAccount(),
      mintProof: getNextAccount(),
      user: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateMintProofInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateMintProofV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([35, 185, 181, 108, 143, 139, 228, 45])
    })
  );
}
function getInitUpdateMintProofV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getInitUpdateMintProofV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getInitUpdateMintProofV2InstructionDataEncoder(),
    getInitUpdateMintProofV2InstructionDataDecoder()
  );
}
async function getInitUpdateMintProofV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofV2Pda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      mint: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateMintProofV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateWhitelistInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["uuid", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
      ["rootHash", web3_js.getOptionEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))],
      ["name", web3_js.getOptionEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))],
      ["voc", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["fvc", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([255, 1, 192, 134, 111, 49, 212, 131])
    })
  );
}
function getInitUpdateWhitelistInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["uuid", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["rootHash", web3_js.getOptionDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))],
    ["name", web3_js.getOptionDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))],
    ["voc", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["fvc", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getInitUpdateWhitelistInstructionDataCodec() {
  return web3_js.combineCodec(
    getInitUpdateWhitelistInstructionDataEncoder(),
    getInitUpdateWhitelistInstructionDataDecoder()
  );
}
async function getInitUpdateWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistPda({
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateWhitelistInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getReallocAuthorityInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([128, 120, 16, 197, 85, 34, 2, 91])
    })
  );
}
function getReallocAuthorityInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getReallocAuthorityInstructionDataCodec() {
  return web3_js.combineCodec(
    getReallocAuthorityInstructionDataEncoder(),
    getReallocAuthorityInstructionDataDecoder()
  );
}
async function getReallocAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocAuthorityInstructionDataDecoder().decode(instruction.data)
  };
}
function getReallocWhitelistInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([173, 147, 168, 152, 181, 46, 55, 60])
    })
  );
}
function getReallocWhitelistInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getReallocWhitelistInstructionDataCodec() {
  return web3_js.combineCodec(
    getReallocWhitelistInstructionDataEncoder(),
    getReallocWhitelistInstructionDataDecoder()
  );
}
async function getReallocWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([215, 119, 9, 92, 160, 139, 226, 253])
    })
  );
}
function getUnfreezeWhitelistInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getUnfreezeWhitelistInstructionDataCodec() {
  return web3_js.combineCodec(
    getUnfreezeWhitelistInstructionDataEncoder(),
    getUnfreezeWhitelistInstructionDataDecoder()
  );
}
async function getUnfreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getUnfreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUnfreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([51, 105, 214, 84, 252, 188, 26, 1])
    })
  );
}
function getUnfreezeWhitelistV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getUnfreezeWhitelistV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getUnfreezeWhitelistV2InstructionDataEncoder(),
    getUnfreezeWhitelistV2InstructionDataDecoder()
  );
}
function getUnfreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getUnfreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getUnfreezeWhitelistV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUpdateWhitelistV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["freezeAuthority", getOperationEncoder()],
      ["conditions", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getConditionEncoder()))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([184, 188, 157, 214, 205, 49, 74, 226])
    })
  );
}
function getUpdateWhitelistV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["freezeAuthority", getOperationDecoder()],
    ["conditions", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getConditionDecoder()))]
  ]);
}
function getUpdateWhitelistV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateWhitelistV2InstructionDataEncoder(),
    getUpdateWhitelistV2InstructionDataDecoder()
  );
}
function getUpdateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    newUpdateAuthority: {
      value: input.newUpdateAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.newUpdateAuthority),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUpdateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_WHITELIST_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      newUpdateAuthority: getNextOptionalAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUpdateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}

// src/helpers.ts
var intoAddress = (data) => {
  const decoder = web3_js.getAddressDecoder();
  return decoder.decode(Uint8Array.from(data));
};
var fromAddress = (address) => {
  const encoder = web3_js.getAddressEncoder();
  return encoder.encode(address);
};
var collIdToBuffer = (collId) => {
  return Buffer.from(collId.split("-").join(""));
};
var bufferToCollId = (buffer) => {
  const raw = String.fromCharCode(...buffer);
  return `${raw.slice(0, 8)}-${raw.slice(8, 12)}-${raw.slice(
    12,
    16
  )}-${raw.slice(16, 20)}-${raw.slice(20)}`;
};
async function getWhitelistFromCollId(collId) {
  const uuid = collIdToBuffer(collId);
  const whitelistSeeds = {
    uuid
  };
  const [whitelistPda] = await findWhitelistPda(whitelistSeeds);
  return whitelistPda;
}

exports.Mode = Mode;
exports.State = State;
exports.TENSOR_WHITELIST_ERROR__BAD_COSIGNER = TENSOR_WHITELIST_ERROR__BAD_COSIGNER;
exports.TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF = TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF;
exports.TENSOR_WHITELIST_ERROR__BAD_OWNER = TENSOR_WHITELIST_ERROR__BAD_OWNER;
exports.TENSOR_WHITELIST_ERROR__BAD_WHITELIST = TENSOR_WHITELIST_ERROR__BAD_WHITELIST;
exports.TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS = TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS;
exports.TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION = TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION;
exports.TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION = TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION;
exports.TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION = TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION;
exports.TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY = TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY;
exports.TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX = TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX;
exports.TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF = TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF;
exports.TENSOR_WHITELIST_ERROR__MISSING_NAME = TENSOR_WHITELIST_ERROR__MISSING_NAME;
exports.TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION = TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION;
exports.TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT = TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT;
exports.TENSOR_WHITELIST_ERROR__NO_CONDITIONS = TENSOR_WHITELIST_ERROR__NO_CONDITIONS;
exports.TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG = TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG;
exports.TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS = TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS;
exports.TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS = TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS;
exports.TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN = TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN;
exports.TENSOR_WHITELIST_PROGRAM_ADDRESS = TENSOR_WHITELIST_PROGRAM_ADDRESS;
exports.TensorWhitelistAccount = TensorWhitelistAccount;
exports.TensorWhitelistInstruction = TensorWhitelistInstruction;
exports.bufferToCollId = bufferToCollId;
exports.collIdToBuffer = collIdToBuffer;
exports.decodeAuthority = decodeAuthority;
exports.decodeMintProof = decodeMintProof;
exports.decodeMintProofV2 = decodeMintProofV2;
exports.decodeWhitelist = decodeWhitelist;
exports.decodeWhitelistV2 = decodeWhitelistV2;
exports.fetchAllAuthority = fetchAllAuthority;
exports.fetchAllMaybeAuthority = fetchAllMaybeAuthority;
exports.fetchAllMaybeMintProof = fetchAllMaybeMintProof;
exports.fetchAllMaybeMintProofV2 = fetchAllMaybeMintProofV2;
exports.fetchAllMaybeWhitelist = fetchAllMaybeWhitelist;
exports.fetchAllMaybeWhitelistV2 = fetchAllMaybeWhitelistV2;
exports.fetchAllMintProof = fetchAllMintProof;
exports.fetchAllMintProofV2 = fetchAllMintProofV2;
exports.fetchAllWhitelist = fetchAllWhitelist;
exports.fetchAllWhitelistV2 = fetchAllWhitelistV2;
exports.fetchAuthority = fetchAuthority;
exports.fetchAuthorityFromSeeds = fetchAuthorityFromSeeds;
exports.fetchMaybeAuthority = fetchMaybeAuthority;
exports.fetchMaybeAuthorityFromSeeds = fetchMaybeAuthorityFromSeeds;
exports.fetchMaybeMintProof = fetchMaybeMintProof;
exports.fetchMaybeMintProofFromSeeds = fetchMaybeMintProofFromSeeds;
exports.fetchMaybeMintProofV2 = fetchMaybeMintProofV2;
exports.fetchMaybeMintProofV2FromSeeds = fetchMaybeMintProofV2FromSeeds;
exports.fetchMaybeWhitelist = fetchMaybeWhitelist;
exports.fetchMaybeWhitelistFromSeeds = fetchMaybeWhitelistFromSeeds;
exports.fetchMaybeWhitelistV2 = fetchMaybeWhitelistV2;
exports.fetchMaybeWhitelistV2FromSeeds = fetchMaybeWhitelistV2FromSeeds;
exports.fetchMintProof = fetchMintProof;
exports.fetchMintProofFromSeeds = fetchMintProofFromSeeds;
exports.fetchMintProofV2 = fetchMintProofV2;
exports.fetchMintProofV2FromSeeds = fetchMintProofV2FromSeeds;
exports.fetchWhitelist = fetchWhitelist;
exports.fetchWhitelistFromSeeds = fetchWhitelistFromSeeds;
exports.fetchWhitelistV2 = fetchWhitelistV2;
exports.fetchWhitelistV2FromSeeds = fetchWhitelistV2FromSeeds;
exports.findAuthorityPda = findAuthorityPda;
exports.findMintProofPda = findMintProofPda;
exports.findMintProofV2Pda = findMintProofV2Pda;
exports.findWhitelistPda = findWhitelistPda;
exports.findWhitelistV2Pda = findWhitelistV2Pda;
exports.fromAddress = fromAddress;
exports.getAuthorityCodec = getAuthorityCodec;
exports.getAuthorityDecoder = getAuthorityDecoder;
exports.getAuthorityEncoder = getAuthorityEncoder;
exports.getAuthoritySize = getAuthoritySize;
exports.getCloseMintProofV2Instruction = getCloseMintProofV2Instruction;
exports.getCloseMintProofV2InstructionDataCodec = getCloseMintProofV2InstructionDataCodec;
exports.getCloseMintProofV2InstructionDataDecoder = getCloseMintProofV2InstructionDataDecoder;
exports.getCloseMintProofV2InstructionDataEncoder = getCloseMintProofV2InstructionDataEncoder;
exports.getConditionCodec = getConditionCodec;
exports.getConditionDecoder = getConditionDecoder;
exports.getConditionEncoder = getConditionEncoder;
exports.getCreateWhitelistV2Instruction = getCreateWhitelistV2Instruction;
exports.getCreateWhitelistV2InstructionAsync = getCreateWhitelistV2InstructionAsync;
exports.getCreateWhitelistV2InstructionDataCodec = getCreateWhitelistV2InstructionDataCodec;
exports.getCreateWhitelistV2InstructionDataDecoder = getCreateWhitelistV2InstructionDataDecoder;
exports.getCreateWhitelistV2InstructionDataEncoder = getCreateWhitelistV2InstructionDataEncoder;
exports.getFreezeWhitelistInstruction = getFreezeWhitelistInstruction;
exports.getFreezeWhitelistInstructionAsync = getFreezeWhitelistInstructionAsync;
exports.getFreezeWhitelistInstructionDataCodec = getFreezeWhitelistInstructionDataCodec;
exports.getFreezeWhitelistInstructionDataDecoder = getFreezeWhitelistInstructionDataDecoder;
exports.getFreezeWhitelistInstructionDataEncoder = getFreezeWhitelistInstructionDataEncoder;
exports.getFreezeWhitelistV2Instruction = getFreezeWhitelistV2Instruction;
exports.getFreezeWhitelistV2InstructionDataCodec = getFreezeWhitelistV2InstructionDataCodec;
exports.getFreezeWhitelistV2InstructionDataDecoder = getFreezeWhitelistV2InstructionDataDecoder;
exports.getFreezeWhitelistV2InstructionDataEncoder = getFreezeWhitelistV2InstructionDataEncoder;
exports.getFullMerkleProofCodec = getFullMerkleProofCodec;
exports.getFullMerkleProofDecoder = getFullMerkleProofDecoder;
exports.getFullMerkleProofEncoder = getFullMerkleProofEncoder;
exports.getInitUpdateAuthorityInstruction = getInitUpdateAuthorityInstruction;
exports.getInitUpdateAuthorityInstructionAsync = getInitUpdateAuthorityInstructionAsync;
exports.getInitUpdateAuthorityInstructionDataCodec = getInitUpdateAuthorityInstructionDataCodec;
exports.getInitUpdateAuthorityInstructionDataDecoder = getInitUpdateAuthorityInstructionDataDecoder;
exports.getInitUpdateAuthorityInstructionDataEncoder = getInitUpdateAuthorityInstructionDataEncoder;
exports.getInitUpdateMintProofInstruction = getInitUpdateMintProofInstruction;
exports.getInitUpdateMintProofInstructionAsync = getInitUpdateMintProofInstructionAsync;
exports.getInitUpdateMintProofInstructionDataCodec = getInitUpdateMintProofInstructionDataCodec;
exports.getInitUpdateMintProofInstructionDataDecoder = getInitUpdateMintProofInstructionDataDecoder;
exports.getInitUpdateMintProofInstructionDataEncoder = getInitUpdateMintProofInstructionDataEncoder;
exports.getInitUpdateMintProofV2Instruction = getInitUpdateMintProofV2Instruction;
exports.getInitUpdateMintProofV2InstructionAsync = getInitUpdateMintProofV2InstructionAsync;
exports.getInitUpdateMintProofV2InstructionDataCodec = getInitUpdateMintProofV2InstructionDataCodec;
exports.getInitUpdateMintProofV2InstructionDataDecoder = getInitUpdateMintProofV2InstructionDataDecoder;
exports.getInitUpdateMintProofV2InstructionDataEncoder = getInitUpdateMintProofV2InstructionDataEncoder;
exports.getInitUpdateWhitelistInstruction = getInitUpdateWhitelistInstruction;
exports.getInitUpdateWhitelistInstructionAsync = getInitUpdateWhitelistInstructionAsync;
exports.getInitUpdateWhitelistInstructionDataCodec = getInitUpdateWhitelistInstructionDataCodec;
exports.getInitUpdateWhitelistInstructionDataDecoder = getInitUpdateWhitelistInstructionDataDecoder;
exports.getInitUpdateWhitelistInstructionDataEncoder = getInitUpdateWhitelistInstructionDataEncoder;
exports.getMintProofCodec = getMintProofCodec;
exports.getMintProofDecoder = getMintProofDecoder;
exports.getMintProofEncoder = getMintProofEncoder;
exports.getMintProofSize = getMintProofSize;
exports.getMintProofV2Codec = getMintProofV2Codec;
exports.getMintProofV2Decoder = getMintProofV2Decoder;
exports.getMintProofV2Encoder = getMintProofV2Encoder;
exports.getMintProofV2Size = getMintProofV2Size;
exports.getModeCodec = getModeCodec;
exports.getModeDecoder = getModeDecoder;
exports.getModeEncoder = getModeEncoder;
exports.getOperationCodec = getOperationCodec;
exports.getOperationDecoder = getOperationDecoder;
exports.getOperationEncoder = getOperationEncoder;
exports.getReallocAuthorityInstruction = getReallocAuthorityInstruction;
exports.getReallocAuthorityInstructionAsync = getReallocAuthorityInstructionAsync;
exports.getReallocAuthorityInstructionDataCodec = getReallocAuthorityInstructionDataCodec;
exports.getReallocAuthorityInstructionDataDecoder = getReallocAuthorityInstructionDataDecoder;
exports.getReallocAuthorityInstructionDataEncoder = getReallocAuthorityInstructionDataEncoder;
exports.getReallocWhitelistInstruction = getReallocWhitelistInstruction;
exports.getReallocWhitelistInstructionAsync = getReallocWhitelistInstructionAsync;
exports.getReallocWhitelistInstructionDataCodec = getReallocWhitelistInstructionDataCodec;
exports.getReallocWhitelistInstructionDataDecoder = getReallocWhitelistInstructionDataDecoder;
exports.getReallocWhitelistInstructionDataEncoder = getReallocWhitelistInstructionDataEncoder;
exports.getStateCodec = getStateCodec;
exports.getStateDecoder = getStateDecoder;
exports.getStateEncoder = getStateEncoder;
exports.getTensorWhitelistErrorMessage = getTensorWhitelistErrorMessage;
exports.getUnfreezeWhitelistInstruction = getUnfreezeWhitelistInstruction;
exports.getUnfreezeWhitelistInstructionAsync = getUnfreezeWhitelistInstructionAsync;
exports.getUnfreezeWhitelistInstructionDataCodec = getUnfreezeWhitelistInstructionDataCodec;
exports.getUnfreezeWhitelistInstructionDataDecoder = getUnfreezeWhitelistInstructionDataDecoder;
exports.getUnfreezeWhitelistInstructionDataEncoder = getUnfreezeWhitelistInstructionDataEncoder;
exports.getUnfreezeWhitelistV2Instruction = getUnfreezeWhitelistV2Instruction;
exports.getUnfreezeWhitelistV2InstructionDataCodec = getUnfreezeWhitelistV2InstructionDataCodec;
exports.getUnfreezeWhitelistV2InstructionDataDecoder = getUnfreezeWhitelistV2InstructionDataDecoder;
exports.getUnfreezeWhitelistV2InstructionDataEncoder = getUnfreezeWhitelistV2InstructionDataEncoder;
exports.getUpdateWhitelistV2Instruction = getUpdateWhitelistV2Instruction;
exports.getUpdateWhitelistV2InstructionDataCodec = getUpdateWhitelistV2InstructionDataCodec;
exports.getUpdateWhitelistV2InstructionDataDecoder = getUpdateWhitelistV2InstructionDataDecoder;
exports.getUpdateWhitelistV2InstructionDataEncoder = getUpdateWhitelistV2InstructionDataEncoder;
exports.getWhitelistCodec = getWhitelistCodec;
exports.getWhitelistDecoder = getWhitelistDecoder;
exports.getWhitelistEncoder = getWhitelistEncoder;
exports.getWhitelistFromCollId = getWhitelistFromCollId;
exports.getWhitelistSize = getWhitelistSize;
exports.getWhitelistV2Codec = getWhitelistV2Codec;
exports.getWhitelistV2Decoder = getWhitelistV2Decoder;
exports.getWhitelistV2Encoder = getWhitelistV2Encoder;
exports.getWhitelistV2Size = getWhitelistV2Size;
exports.identifyTensorWhitelistAccount = identifyTensorWhitelistAccount;
exports.identifyTensorWhitelistInstruction = identifyTensorWhitelistInstruction;
exports.intoAddress = intoAddress;
exports.isOperation = isOperation;
exports.operation = operation;
exports.parseCloseMintProofV2Instruction = parseCloseMintProofV2Instruction;
exports.parseCreateWhitelistV2Instruction = parseCreateWhitelistV2Instruction;
exports.parseFreezeWhitelistInstruction = parseFreezeWhitelistInstruction;
exports.parseFreezeWhitelistV2Instruction = parseFreezeWhitelistV2Instruction;
exports.parseInitUpdateAuthorityInstruction = parseInitUpdateAuthorityInstruction;
exports.parseInitUpdateMintProofInstruction = parseInitUpdateMintProofInstruction;
exports.parseInitUpdateMintProofV2Instruction = parseInitUpdateMintProofV2Instruction;
exports.parseInitUpdateWhitelistInstruction = parseInitUpdateWhitelistInstruction;
exports.parseReallocAuthorityInstruction = parseReallocAuthorityInstruction;
exports.parseReallocWhitelistInstruction = parseReallocWhitelistInstruction;
exports.parseUnfreezeWhitelistInstruction = parseUnfreezeWhitelistInstruction;
exports.parseUnfreezeWhitelistV2Instruction = parseUnfreezeWhitelistV2Instruction;
exports.parseUpdateWhitelistV2Instruction = parseUpdateWhitelistV2Instruction;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map